**Robo-Time** 


Clocks, timing, and timestamp functionality for mobile robotics and other applications

* Includes 3 fundamental clocks: Uptime Clock, System Clock, and World Clock (NTP/UTC)

* Intuitive commands for basic uptime, timedate and timestamp outputs

* Choice of either command line mode or output mode for most interface functions

* Output formats have commonly used options and forms that allow easy and flexible reformatting for specific requirements.
  


.

Installation:

$ **pip** install robo-time


For documentation see https://robo-time.readthedocs.io/en/latest/







